# FILE: avf2ovf.tcl
#
# This file must be evaluated by mmDispSh

package require Oc 1.1.1.0
package require Mmdispcmds 1.1.1.0
Oc_ForceNoTkDefaultMessage
catch {wm withdraw .}

Oc_Main SetAppName avf2ovf
Oc_Main SetVersion 1.2.0.0

Oc_CommandLine Option console {} {}
Oc_CommandLine Option format {
	{format {regexp {text|b4|b8} $format} {is one of {text,b4,b8}}}
    } {
	upvar #0 format globalformat; set globalformat $format
} {Format of output file: text, 4-, or 8-byte binary}
set format text

Oc_CommandLine Option grid {
	{type {regexp {reg|irreg} $type} {is one of {reg,irreg}}}
    } {
	global grid; set grid $type
} {Grid type of output file: regular or irregular}
set grid reg

Oc_CommandLine Option [Oc_CommandLine Switch] {
	{file {} {Input vector field file}}
    } {
	global infile; set infile $file
} {End of options; next argument is file}
Oc_CommandLine Parse $argv
 
array set formatmap {
	text	text
	b4	binary4
	b8	binary8
}
array set gridmap {
	reg	regular
	irreg	irregular
}

ChangeMesh [Oc_DirectPathname $infile] 0 0 0 -1
set title [GetMeshTitle]
set desc [GetMeshDescription]
if {[string match Vf_GeneralMesh3f [GetMeshType]] &&
	![string match irregular $gridmap($grid)]} {
    puts stderr "Input file has irregular grid; so must output."
}

puts stderr "Copying Title field: $title\nYou may want to edit this\
	field in the output by hand."

# $filename == "" --> write to stdout
WriteMesh "" $formatmap($format) $gridmap($grid) $title $desc

exit 0
