/* FILE: energy.h                 -*-Mode: c++-*-
 *
 * Abstract energy class, derived from Oxs_Ext class.
 *
 */

#ifndef _OXS_ENERGY
#define _OXS_ENERGY

#include "ext.h"
#include "simstate.h"
#include "key.h"
#include "meshvalue.h"
#include "output.h"

/* End includes */

class Oxs_Energy:public Oxs_Ext {
protected:
  Oxs_Energy(const char* name,      // Child instance id
             Oxs_Director* newdtr); // App director
  Oxs_Energy(const char* name,
             Oxs_Director* newdtr,
             Tcl_Interp* safe_interp, // Safe interpreter
	     const char* argstr);   // MIF block argument string

  // Standard outputs presented by all energy objects.  These are
  // conceptually public, but are specified private to force clients
  // to use the Oxs_Director output_map interface.
  void UpdateStandardOutputs(const Oxs_SimState&);
  Oxs_ScalarOutput<Oxs_Energy> energy_sum_output;
  Oxs_VectorFieldOutput<Oxs_Energy> field_output;


  // Field and energy calculation function.  This should be
  // "conceptually const."  The energy return is average energy
  // density for the corresponding cell, in J/m^3.  The field
  // is in A/m.
  //   There are two GetEnergyAndField functions.  The first is
  // a private, virtual member function of Oxs_Energy.  It takes
  // as imports Oxs_MeshValue references into which to store
  // the results.  The second is a non-virtual public member
  // function that passes in Oxs_MeshValue references that *may*
  // be used to store the results, and separate parameters that
  // return pointers to where the results actually were stored.
  // If output caching in enabled, the Oxs_Energy base class calls
  // the virtual GetEnergyAndField function with references to the
  // output cache Oxs_MeshValue objects.  Otherwise the import
  // buffer space is used.
  virtual void GetEnergyAndField(const Oxs_SimState& state,
                                 Oxs_MeshValue<REAL8m>& energy,
                                 Oxs_MeshValue<ThreeVector>& field
                                 ) const =0;

public:

  virtual ~Oxs_Energy();

  void GetEnergyAndField(const Oxs_SimState& state,
			 Oxs_MeshValue<REAL8m>& energy_provided,
			 const Oxs_MeshValue<REAL8m>* &energy_used,
			 Oxs_MeshValue<ThreeVector>& field_provided,
			 const Oxs_MeshValue<ThreeVector>* &field_used
			 );
  /// Note: The *_used are references to pointers, because C++ does
  ///       not support references to references.
};


#endif // _OXS_ENERGY
